@@ -1,12 +1,12 @@
 from pyspark.sql.functions import udf  # type: ignore
 from pyspark.sql.types import DoubleType, StringType  # type: ignore
-
 from diffprivlib.mechanisms import LaplaceTruncated, Binary  # type: ignore
+from tabulate import tabulate  # type: ignore
 
 # Following imports provide type checking functionality to the library
 from pyspark.sql.dataframe import DataFrame as SparkDataFrame  # type: ignore
 from numbers import Real  # type: ignore
-from typing import Dict, Union, Optional  # type: ignore
+from typing import List, Dict, Union, Optional  # type: ignore
 import sys  # type: ignore
 
 if sys.version_info >= (3, 8):
@@ -59,7 +59,7 @@ class DPLib:
         execute: changes existing sdf to be differentially private. This change is not reversible.
 
     Examples:
-        Check out the example.ipynb Jupyter notebook
+        Check out `differential_preserver_demo.ipynb` Jupyter notebook
 
     """
 
@@ -167,11 +167,11 @@ class DPLib:
             raise ValueError("Labels must not match")
 
         # finds unique values in a column
-        labels: list = [row[column_name] for row in sdf.select(column_name).distinct().collect()]
-        
+        labels: List[str] = [row[column_name] for row in sdf.select(column_name).distinct().collect()]
+
         if len(labels) is not 2 or label1 not in labels or label2 not in labels:
             # checks whether all the rows of column have either label1 or label2
-            raise ValueError("Column has multiple unique labels")
+            raise ValueError("Labels in column `%s` does not match with labels entered" % column_name)
 
         return True
 
@@ -199,6 +199,24 @@ class DPLib:
 
         return True
 
+    @staticmethod
+    def __check_sdf(sdf: SparkDataFrame) -> bool:
+        r"""
+
+        Args:
+            sdf: Spark DataFrame
+
+        Returns: True if sdf satisfies the condition
+
+        Raises: TypeError if sdf does not obey the rules
+
+        """
+
+        if sdf is not None and not isinstance(sdf, SparkDataFrame):
+            raise TypeError('Given sdf is not a Spark DataFrame')
+
+        return True
+
     def set_global_epsilon_delta(self, epsilon: Union[int, float], delta: Union[int, float] = 0.0) -> None:
         r"""  set global epsilon and delta if they satisfy method `__check_epsilon_delta`
 
@@ -237,7 +255,7 @@ class DPLib:
 
         """
 
-        if isinstance(sdf, SparkDataFrame):
+        if self.__check_sdf(sdf):
             self.sdf = sdf
 
     def set_column(self, column_name: str, category: str,
@@ -280,12 +298,13 @@ class DPLib:
 
         if self.sdf is None:
             raise ValueError("Add an eligible Spark DataFrame before adding columns")
+        self.__check_sdf(self.sdf)
 
         if column_name not in self.sdf.columns:
             raise ValueError("Cannot find column in given DataFrame")
 
         if category not in ['numeric', 'boolean']:
-            raise ValueError("Cannot find category in available list")
+            raise ValueError("category must be either `numeric` or `boolean`")
 
         column: Column = {'category': category}
 
@@ -333,23 +352,93 @@ class DPLib:
 
         self.__columns[str(column_name)] = column
 
+    def drop_column(self, *columns: str) -> None:
+        """ drops a column added using `add_column()` method from `self.__columns`
+
+        Args:
+            *columns: one or more column names in string format separated by comma
+                        if '*' is given, all columns will be dropped
+
+        """
+
+        if len(columns) == 1 and '*' in columns:
+            self.__columns = {}
+        else:
+            for column in columns:
+                if column in self.__columns:
+                    del self.__columns[column]
+
+    def get_config(self) -> None:
+
+        print('Global parameters')
+        print('-----------------\n')
+
+        global_table: List[List[Union[float, str]]] = [
+            ['Epsilon', self.__epsilon if self.__epsilon is not None else '--'],
+            ['Delta', self.__delta if self.__delta is not None else '--'],
+            ['Sensitivity', self.__sensitivity if self.__sensitivity is not None else '--']
+        ]
+
+        print(tabulate(tabular_data=global_table,
+                       tablefmt='plain',
+                       disable_numparse=True))
+
+        print('\n')
+        print('Column specific parameters')
+        print('--------------------------\n')
+
+        column_table: List[List] = []
+
+        for column_name, details in self.__columns.items():
+            row: List = [column_name,
+                         details['category'],
+                         details['epsilon'] if 'epsilon' in details else '--',
+                         details['delta'] if 'delta' in details else '--',
+                         details['sensitivity'] if 'sensitivity' in details else '--',
+                         details['lower_bound'] if 'lower_bound' in details else '--',
+                         details['upper_bound'] if 'upper_bound' in details else '--',
+                         details['round'] if 'round' in details else '--',
+                         details['label1'] if 'label1' in details else '--',
+                         details['label2'] if 'label2' in details else '--'
+                         ]
+            column_table.append(row)
+
+        if self.sdf is not None and isinstance(self.sdf, SparkDataFrame):
+            for column in self.sdf.columns:
+                if column not in self.__columns:
+                    row = [column]
+                    row += '--' * 9
+                    column_table.append(row)
+
+        print(tabulate(tabular_data=column_table,
+                       tablefmt='github',
+                       disable_numparse=True,
+                       headers=['Column name', 'Column category', 'Epsilon', 'Delta', 'Sensitivity', 'Lower bound',
+                                'Upper bound', 'Round', 'Label 1', 'Label 2']
+                       )
+              )
+
     def execute(self):
         r"""
 
         Raises:
-            The method itself will not raise any exceptions.
-            However inner methods may raise Exception, only if parameters have not been set correctly
+            ValueError: if self.__columns is empty
+            inner methods may raise Exception, only if parameters have not been set correctly
 
         """
 
-        laplace = LaplaceTruncated()
-        binary = Binary()
+        laplace: LaplaceTruncated = LaplaceTruncated()
+        binary: Binary = Binary()
+
+        if self.__columns == {}:
+            raise ValueError('No columns added for execution')
 
         for column_name, details in self.__columns.items():
 
             if details['category'] is 'numeric':
 
-                self.sdf = self.sdf.withColumn(column_name, self.sdf[column_name].cast(DoubleType()))
+                self.sdf = self.sdf.withColumn(colName=column_name,
+                                               col=self.sdf[column_name].cast(DoubleType()))
 
                 laplace.set_epsilon_delta(epsilon=details['epsilon'], delta=details['delta'])
                 laplace.set_sensitivity(details['sensitivity'])
@@ -362,7 +451,8 @@ class DPLib:
 
                     round_randomise_udf = udf(f=round_randomise, returnType=DoubleType())
 
-                    self.sdf = self.sdf.withColumn(column_name, round_randomise_udf(column_name))
+                    self.sdf = self.sdf.withColumn(colName=column_name,
+                                                   col=round_randomise_udf(column_name))
 
                 else:
 
@@ -371,11 +461,13 @@ class DPLib:
 
                     randomise_udf = udf(f=randomise, returnType=DoubleType())
 
-                    self.sdf = self.sdf.withColumn(column_name, randomise_udf(column_name))
+                    self.sdf = self.sdf.withColumn(colName=column_name,
+                                                   col=randomise_udf(column_name))
 
             elif details['category'] is 'boolean':
 
-                self.sdf = self.sdf.withColumn(column_name, self.sdf[column_name].cast(StringType()))
+                self.sdf = self.sdf.withColumn(colName=column_name,
+                                               col=self.sdf[column_name].cast(StringType()))
 
                 binary.set_epsilon_delta(epsilon=details['epsilon'], delta=details['delta'])
                 binary.set_labels(value0=details['label1'], value1=details['label2'])
@@ -385,4 +477,5 @@ class DPLib:
 
                 randomise_udf = udf(f=randomise, returnType=StringType())
 
-                self.sdf = self.sdf.withColumn(column_name, randomise_udf(column_name))
+                self.sdf = self.sdf.withColumn(colName=column_name,
+                                               col=randomise_udf(column_name))
